@@ -13,21 +13,21 @@ import keyboard
 import time
 from Cogenvdecoder import  UdpComms as U
 
-num_vector = 7
+
 
 
 class CogEnvDecoder:
-    def __init__(self, size=(400, 400), train=True, allow_multiple_obs=True, env_name='RealGame.exe', mat_num=0):
+    def __init__(self, train=True, allow_multiple_obs=True, env_name='RealGame.exe', mat_num=0, no_graphics=False, time_scale=1):
         if train:
             engine_configuration_channel = EngineConfigurationChannel()
-            engine_configuration_channel.set_configuration_parameters(width=100, height=100, time_scale=100)
-            unity_env = UnityEnvironment(env_name, worker_id=2)
+            engine_configuration_channel.set_configuration_parameters(width=100, height=100, time_scale=time_scale)
+            unity_env = UnityEnvironment(env_name, worker_id=2, no_graphics=no_graphics)
             self._env = UnityToGymWrapper(unity_env)
         else:
             unity_env = UnityEnvironment(env_name, worker_id=1)
             self._env = UnityToGymWrapper(unity_env)
 
-        self._size = size
+        self._size = (300,300)
         # print(self._env.reward_range)
         self.reward_range = self._env.reward_range
         self.metadata = self._env.metadata
@@ -38,21 +38,24 @@ class CogEnvDecoder:
         self.depth_sock = U.UdpComms(udpIP="127.0.0.1", portTX=8002, portRX=8003,enableRX=True, suppressWarnings=True)
         self.last_frame = np.zeros((100, 100), dtype=np.uint8)
         self.last_depth_frame = np.zeros((100, 100), dtype=np.uint8)
-        if env_name == 'RealGame.exe':
-            data = open("RealGame_Data/data.txt", "w")
-            data.write(str(mat_num))
-            data.close()
-        elif env_name == '1.x86_64':
-            data = open("data.txt", "w")
-            data.write(str(mat_num))
-            data.close()
+        self._load_step = False #allow action transfer to run
+        self._obs = None
+        self._reward = None
+        self._done = None
+        self._info = None
+        data = open("RealGame_Data/data.txt", "w")
+        data.write(str(mat_num))
+        data.close()
+
 
     @property
     def observation_space(self):
         shape_image = self._size + (3,)
-        space_image = gym.spaces.Box(low=0, high=255, shape=shape_image, dtype=np.uint8)
+        color_image = gym.spaces.Box(low=0, high=255, shape=shape_image, dtype=np.uint8)
+        num_vector  =26
         space_vector = gym.spaces.Box(low=-np.Inf, high=np.Inf, shape=(num_vector,), dtype=np.float32)
-        return gym.spaces.Dict({'image': space_image, 'vector': space_vector})
+        depth_image = gym.spaces.Box(low=0, high=255, shape=shape_image, dtype=np.uint8)
+        return gym.spaces.Dict({'color_image': space_image, 'depth_image': depthimage, 'vector': space_vector})
         # return space_image
 
     @property
@@ -86,6 +89,7 @@ class CogEnvDecoder:
         action_tuple = ActionTuple()
         action_tuple.add_continuous(action)
         self._env._env.set_actions(self._env.name, action_tuple)
+        '''
         decision_step, terminal_step = self._env._env.get_steps(self._env.name)
         self._env._check_agents(max(len(decision_step), len(terminal_step)))
         #print(self._env.name)
@@ -95,11 +99,17 @@ class CogEnvDecoder:
             return self._env._single_step(terminal_step)
         else:
             return self._env._single_step(decision_step)
-
+        '''
     def step_action(self, action):
+        #obs, reward, done, info = self.action_transfer(action)
         obs, reward, done, info = self._env.step(action)
-        # obs = self._get_obs(obs)
-
+        #start = time.time()
+        #self.action_transfer(action)
+        #print(time.time() - start)
+        #obs = self._obs
+        #reward = self._reward
+        #done = self._done
+        #info = self._info
         img = self.read_img()
         depth_img = self.read_depth_img()
         self_pos = self._GetSelfPos(obs)  # Blue one Position
@@ -115,10 +125,10 @@ class CogEnvDecoder:
         score = self._Score(obs)  # Current score
         self_info = self._SelfInfo(obs)  # Blue one remaining HP & bullet
         dmg = self._DmgCaused(obs)  # blue one caused damage to red one
-        time = self._TimeTaken(obs)  # Time passed in the round
+        time_taken = self._TimeTaken(obs)  # Time passed in the round
         collision_info = self._CollCondtion(obs)  # collision times and continuous collision time
         final_obs = [img, self_pos, enemy_pos, self_info, goal1, goal2, goal3, goal4, goal5, collision_info, depth_img]
-        judge_result = [score, flag_ach, enemy_act, enemy_info, dmg, time]
+        judge_result = [score, flag_ach, enemy_act, enemy_info, dmg, time_taken]
         return final_obs, reward, done, [info, judge_result]
 
     def render(self, mode):
@@ -291,13 +301,22 @@ class CogEnvDecoder:
         coll_time = data[23]
         cont_coll_time = data[24]
         return [coll_time, cont_coll_time]
-'''
+
     def _thread_step(self):
         quit = False
         #print('1')
         while True:
             self._env._env.step()
-            time.sleep(0.02)
+            decision_step, terminal_step = self._env._env.get_steps(self._env.name)
+            self._env._check_agents(max(len(decision_step), len(terminal_step)))
+            # print(self._env.name)
+            if len(terminal_step) != 0:
+                # The agent is done
+                self._env.game_over = True
+                self._obs, self._reward, self._done, self._info =  self._env._single_step(terminal_step)
+            else:
+                self._obs, self._reward, self._done, self._info =  self._env._single_step(decision_step)
+            #time.sleep(0.02)
             if self._end_thread == True:
                 return
 
@@ -312,4 +331,3 @@ class CogEnvDecoder:
         #self._thread.join()
         #print('4')
 
-'''
\ No newline at end of file
